package org.fax4j.bridge.email;

import org.fax4j.bridge.FaxBridge;
import org.fax4j.bridge.FileInfo;

/**
 * This interface defines the email2fax capabilities of the fax bridge.<br>
 * Email based bridge would probably not have much information to provide the fax client
 * and therefore has email specific bridge capabilities.
 * <br>
 * Below table describes the configuration values relevant for this class.<br>
 * <b>Configuration:</b>
 * <table border="1">
 * 	<tr>
 * 		<td>Name</td>
 * 		<td>Description</td>
 * 		<td>Preconfigured Value</td>
 * 		<td>Default Value</td>
 * 		<td>Mandatory</td>
 * </tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.vendor.policy.class.name</td>
 * 		<td>The vendor policy class name.</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>false</td>
 * 	</tr>
 * </table>
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.40.6
 */
public interface Email2FaxBridge extends FaxBridge
{
	/**
	 * This function will submit a new fax job.
	 * 
	 * @param	targetAddress
	 * 			The fax job target address
	 * @param	senderEmail
	 * 			The fax job sender email address
	 * @param	fileInfo
	 * 			The file information of the requested fax
	 */
	public void submitFaxJob(String targetAddress,String senderEmail,FileInfo fileInfo);
}