package org.fax4j.bridge.email;

import org.fax4j.FaxJob;
import org.fax4j.bridge.FaxBridgeImpl;
import org.fax4j.bridge.FileInfo;

/**
 * This is the email2fax based implementation of the fax bridge.
 * <br>
 * Below table describes the configuration values relevant for this class.<br>
 * <b>Configuration:</b>
 * <table border="1">
 * 	<tr>
 * 		<td>Name</td>
 * 		<td>Description</td>
 * 		<td>Preconfigured Value</td>
 * 		<td>Default Value</td>
 * 		<td>Mandatory</td>
 * </tr>
 * 	<tr>
 * 		<td>org.fax4j.bridge.vendor.policy.class.name</td>
 * 		<td>The vendor policy class name.</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>org.fax4j.bridge.EmptyVendorPolicy</td>
 * 		<td>false</td>
 * 	</tr>
 * </table>
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.40.6
 */
public class Email2FaxBridgeImpl extends FaxBridgeImpl implements Email2FaxBridge
{
	/**
	 * This is the class constructor.
	 */
	public Email2FaxBridgeImpl()
	{
		super();
	}

	/**
	 * This function will submit a new fax job.
	 * 
	 * @param	targetAddress
	 * 			The fax job target address
	 * @param	senderEmail
	 * 			The fax job sender email address
	 * @param	fileInfo
	 * 			The file information of the requested fax
	 */
	public void submitFaxJob(String targetAddress,String senderEmail,FileInfo fileInfo)
	{
		//create fax job
		FaxJob faxJob=this.createFaxJob(targetAddress,senderEmail);
		
		//submit fax job
		this.submitFaxJob(faxJob,fileInfo);
	}
	
	/**
	 * This function creates a new fax job from the provided input.
	 * 
	 * @param	targetAddress
	 * 			The fax job target address
	 * @param	senderEmail
	 * 			The fax job sender email address
	 * @return	The fax job
	 */
	protected FaxJob createFaxJob(String targetAddress,String senderEmail)
	{
		//create fax job
		FaxJob faxJob=this.createFaxJob();

		//populate fax job
		faxJob.setTargetAddress(targetAddress);
		faxJob.setSenderEmail(senderEmail);

		return faxJob;
	}
}