package org.fax4j.bridge.http;

import java.util.Map;
import org.fax4j.FaxJob;
import org.fax4j.bridge.FileInfo;
import org.fax4j.spi.http.HTTPRequest;

/**
 * This interface defines the HTTP parser used to extract the fax job
 * and file info from the HTTP request.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.40.6
 */
public interface HTTPRequestParser
{
	/**
	 * This function initializes the parser.
	 * 
	 * @param	configuration
	 * 			The parser configuration
	 */
	public void initialize(Map<String,String> configuration);

	/**
	 * This function returns the file info from the request data.
	 * 
	 * @param	request
	 * 			The HTTP request
	 * @return	The file info
	 */
	public FileInfo getFileInfoFromRequest(HTTPRequest request);
	
	/**
	 * This function update the fax job from the request data.<br>
	 * This fax job will not have any file data.
	 * 
	 * @param	request
	 * 			The HTTP request
	 * @param	faxJob
	 * 			The fax job to update
	 */
	public void updateFaxJobFromRequest(HTTPRequest request,FaxJob faxJob);
}