package org.fax4j.bridge.process;

import java.util.Map;
import org.fax4j.FaxJob;
import org.fax4j.bridge.FileInfo;

/**
 * This interface defines the command line parser used to extract the fax job
 * and file info from the command line arguments.
 * 
 * @author 	Sagie Gur-Ari
 * @version 1.0
 * @since	0.40.6
 */
public interface CommandLineArgumentsParser
{
	/**
	 * This function initializes the parser.
	 * 
	 * @param	configuration
	 * 			The parser configuration
	 */
	public void initialize(Map<String,String> configuration);
	
	/**
	 * This function returns the file info from the input data.
	 * 
	 * @param	commandLineArguments
	 * 			The command line arguments
	 * @return	The file info
	 */
	public FileInfo getFileInfoFromArguments(String[] commandLineArguments);

	/**
	 * This function update the fax job from the input data.<br>
	 * This fax job will not have any file data.
	 * 
	 * @param	commandLineArguments
	 * 			The command line arguments
	 * @param	faxJob
	 * 			The fax job to update
	 */
	public void updateFaxJobFromArguments(String[] commandLineArguments,FaxJob faxJob);
}